#
# spec file for package blueprint-compiler
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           blueprint-compiler
Version:        0.14.0
Release:        1.1
Summary:        A markup language for GTK user interfaces
License:        LGPL-3.0-or-later
URL:            https://gitlab.gnome.org/jwestman/blueprint-compiler
Source:         %{url}/-/archive/v%{version}/%{name}-v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  meson
BuildRequires:  python3-Sphinx
BuildRequires:  python3-gobject
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
Requires:       python3-gobject
BuildArch:      noarch

%description
A markup language for GTK user interface files.

%package devel
Summary:        Development files for blueprint-compiler
Requires:       blueprint-compiler = %{version}

%description devel
A markup language for GTK user interface files.

%prep
%autosetup -n %{name}-v%{version}

%build
%meson \
  -Ddocs=true
%meson_build

%install
%meson_install

sed -i '1s|#!/usr/bin/env |#!/usr/bin/|' %{buildroot}%{_bindir}/blueprint-compiler

#%check
#python3 -m unittest

%files
%license COPYING
%doc README.md NEWS.md
%{_bindir}/blueprint-compiler
%{python_sitelib}/blueprintcompiler

%files devel
%{_datadir}/pkgconfig/blueprint-compiler.pc

%changelog
* Sun Aug 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.14.0:
  * Added a warning for unused imports.
  * Added an option to not print the diff when formatting with the CLI.
  * Added support for building Gtk.ColumnViewRow, Gtk.ColumnViewCell,
  * and Gtk.ListHeader widgets with Gtk.BuilderListItemFactory.
  * Added support for the after keyword for signals. This was previously
  * documented but not implemented.
  * Added support for string arrays.
  * Added hover documentation for properties in lookup expressions.
  * The decompiler supports action widgets, translation domains, typeof<>
  * syntax, and expressions. It also supports extension syntax for
  * Adw.Breakpoint, Gtk.BuilderListItemFactory, Gtk.ComboBoxText,
  * Gtk.SizeGroup, and Gtk.StringList.
  * Added a decompile subcommand to the CLI, which decompiles an XML .ui
  * file to blueprint.
  * Accessibility relations that allow multiple values are supported
  * using list syntax.
  * The decompiler sorts imports alphabetically.
  * Translatable strings use translatable="yes" instead of translatable="true"
  * for compatibility with xgettext.
  * The first line of the documentation is shown in the completion list
  * when using the language server.
  * Object autocomplete uses a snippet to add the braces and position the
  * cursor inside them.
  * The carets in the CLI diagnostic output now span the whole error
  * message up to the end of the first line, rather than just the first
  * character.
  * The decompiler emits double quotes, which are compatible with gettext.
  * Fixed deprecation warnings in the language server.
  * The decompiler no longer duplicates translator comments on properties.
  * Subtemplates no longer output a redundant @generated comment.
  * When extension syntax from a library that is not available is used,
  * the compiler emits an error instead of crashing.
  * The language server reports semantic token positions correctly.
  * The decompiler no longer emits the deprecated bind-property syntax.
  * Fixed the tests when used as a Meson subproject.
  * Signal autocomplete generates correct syntax.
  * The decompiler supports templates that do not specify a parent class.
  * Adw.Breakpoint setters that set a property on the template no longer cause a crash.
  * Fixed type checking with templates that do not have a parent class.
  * Fixed online documentation links for interfaces.
  * The wording of edit suggestions is fixed for insertions and deletions.
  * When an input file uses tabs instead of spaces, the diagnostic output
  * on the CLI aligns the caret correctly.
  * The decompiler emits correct syntax when a property binding refers to
  * the template object.
  * Fixed typos in "Built with Blueprint" section.
- build documentation
- remove tests, as they fail on obs, but work otherwise fine when build locally
* Mon Mar 25 2024 Richard Rahl <rrahl0@proton.me>
- Update to version 0.12.0:
  + Add support for Adw.AlertDialog
  + Emit warnings for deprecated APIs
  + Document symbols
  + "Go to definition" (ctrl+click)
  + Code action for "namespace not imported" diagnostics, that adds the
    missing import
  + Add a formatter - cli and lsp
  + Support for translation domain
  + Print code actions in error messages
  + Add a header notice mentionning the file is generated
  + decompiler: Use single quotes for output
  + Fixed multine strings support with the escape newline character
  + Fixed the signal completion, which was missing the "$"
  + Fixed property value completion
  + Added a missing semantic highlight (for the enum in Gtk.Scale marks)
  + Handle big endian bitfields correctly
  + Fix mixing relative and absolute paths
* Mon Dec 18 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Revert python3-gobject Requires: fix No module named 'gi'
* Sat Dec  9 2023 Richard Rahl <rrahl0@proton.me>
- Update to version 0.10.0:
  + The bind-property keyword has been removed. Use bind instead.
  + Fixed an issue with the language server not conforming the spec.
  + Fixed the signature section of the hover documentation
    for properties and signals.
  + Fixed a bug where documentation was sometimes shown
    for a different symbol with the same name.
  + Number literals are now correctly parsed as floats
  + Decompiling an empty file now produces an empty file
  + Added hover documentation for the Adw.Breakpoint extensions
- Update to version 0.8.1:
  + Duplicates in a number of places are now considered errors.
  + Fixed a number of bugs in the XML output
- Update to version 0.8.0:
  + Fixed a bug in the language server's acceptance of text
    change commands.
  + Fixed a bug in the display of diagnostics when the diagnostic
    is at the beginning of a line.
  + Fixed a crash that occurred when dealing with array types.
  + Fixed a bug that prevented Gio.File properties from
    being settable.
  + Added support for closure expressions.
  + Added cast expressions, which are sometimes needed to specify
    type information in expressions.
  + Added the --typelib-path command line argument, which allows
    adding directories to the search path for typelib files.
  + Added custom compile and decompile commands to
    the language server.
  + Added support for Adw.MessageDialog custom syntax.
  + Added support for inline sub-templates for
    Gtk.BuilderListItemFactory.
  + Added support for Adw.Breakpoint custom syntax.
  + Added a warning when an object ID might be confusing.
  + Added support for Gtk.Scale custom syntax.
  + The XML output uses the integer value rather than GIR name
    for enum values.
  + Compiler errors are now printed to stderr rather than stdout.
  + Introduced $ to indicate types or callbacks
  + When a namespace is not found, errors are supressed
    when the namespace is used.
  + The compiler bug message now reports the version of
    blueprint-compiler.
  + The typeof syntax now uses <> instead of () to match
    cast expressions.
  + Menu sections and subsections can now have an ID.
  + The interactive porting tool now ignores hidden folders.
  + Templates now use the typename syntax rather than an ID
    to specify the template's class.
* Thu Feb 16 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 0.6.0:
  + Quoted and numeric literals are no longer interchangeable (e.g.
    `"800"` is no longer an accepted value for an integer type).
  + Boxed types are now type checked.
  + Added: There is now syntax for `GType` literals: the `typeof()`
    pseudo-function. For example, list stores have an `item-type`
    property which is now specifiable like this:
    `item-type: typeof(.MyDataModel)`.
  + The language server now logs to stderr.
  + Fix the build on Windows, where backslashes in paths were not
    escaped. (William Roy)
  + Remove the syntax for specifying menu objects inline,
    since it does not work.
  + Fix a crash in the language server that was triggered in files
    with incomplete `using Gtk 4.0;` statements.
  + Fixed compilation on big-endian systems.
  + Fix an issue in the interactive port tool that would lead to
    missed files. (Frank Dana)
  + Fix an issue for documentation contributors where changing the
    documentation files would not trigger a rebuild.
  + Document the missing support for Gtk.Label `<attributes>`,
    which is intentional, and recommend alternatives. (Sonny Piers)
  + Add a prominent warning that Blueprint is still experimental
* Sat Sep 24 2022 Lukas Müller <expeehaa@outlook.com>
- Create initial package.
